Learn R Programming

BSBT (version 1.2.1)

forcedmarriage.comparisons: Comparative Judgment on Forced Marriage in Nottinghamshire, UK

Description

A comparative judgment data set for risk of forced marriage at ward level in Nottinghamshire. There are 12 judges and 76 wards. Each comparison was made from 2 randomly selected wards. The time of each comparision is also included.

Usage

forcedmarriage.comparisons

Arguments

Format

A csv file containing 1846 rows and 4 columns. Each row corresponds to a judgement made by a single judge. Columns 3 and 4 shows which of the pair of wards was judged to have relatively higher and low forced marriage risk level, column 1 shows which judge the comparison belong to, and column 2 shows what time they made the decision.